@@ -18,16 +18,17 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <qfileinfo.h>
-#include <qdir.h>
+#include "disks.h"
+
+#include <QtCore/QFileInfo>
+#include <QtCore/QDir>
 
 #include <kglobal.h>
 #include <kdebug.h>
 
-#include "disks.h"
 #include "disks.moc"
 
 /****************************************************/
@@ -37,8 +38,9 @@
 /**
   * Constructor
 **/
-void DiskEntry::init()
+void DiskEntry::init(const char *name)
 {
+  setObjectName(name);
   device="";
   type="";
   mountedOn="";
@@ -46,35 +48,35 @@ void DiskEntry::init()
   size=0;
   used=0;
   avail=0;
-  isMounted=FALSE;
+  isMounted=false;
   mntcmd="";
   umntcmd="";
-  iconSetByUser=FALSE;
+  iconSetByUser=false;
   icoName="";
 
 
  // BackgroundProcesses ****************************************
 
- sysProc = new KShellProcess(); Q_CHECK_PTR(sysProc);
- connect( sysProc, SIGNAL(receivedStdout(KProcess *, char *, int) ),
-        this, SLOT (receivedSysStdErrOut(KProcess *, char *, int)) );
- connect( sysProc, SIGNAL(receivedStderr(KProcess *, char *, int) ),
-        this, SLOT (receivedSysStdErrOut(KProcess *, char *, int)) );
- readingSysStdErrOut=FALSE;
+ sysProc = new K3ShellProcess(); Q_CHECK_PTR(sysProc);
+ connect( sysProc, SIGNAL(receivedStdout(K3Process *, char *, int) ),
+        this, SLOT (receivedSysStdErrOut(K3Process *, char *, int)) );
+ connect( sysProc, SIGNAL(receivedStderr(K3Process *, char *, int) ),
+        this, SLOT (receivedSysStdErrOut(K3Process *, char *, int)) );
+ readingSysStdErrOut=false;
 
 
 }
 
 DiskEntry::DiskEntry(QObject *parent, const char *name)
- : QObject (parent, name)
+ : QObject (parent)
 {
-  init();
+  init(name);
 }
 
 DiskEntry::DiskEntry(const QString & deviceName, QObject *parent, const char *name)
- : QObject (parent, name)
+ : QObject (parent)
 {
-  init();
+  init(name);
 
   setDeviceName(deviceName);
 }
@@ -112,16 +114,16 @@ int DiskEntry::mount()
   cmdS.replace(QString::fromLatin1("%t"),fsType());
   cmdS.replace(QString::fromLatin1("%o"),mountOptions());
 
-  kdDebug() << "mount-cmd: [" << cmdS << "]" << endl;
+  kDebug() << "mount-cmd: [" << cmdS << "]" ;
   int e=sysCall(cmdS);
-  if (!e) setMounted(TRUE);
-  kdDebug() << "mount-cmd: e=" << e << endl;
+  if (!e) setMounted(true);
+  kDebug() << "mount-cmd: e=" << e ;
   return e;
 }
 
 int DiskEntry::umount()
 {
-  kdDebug() << "umounting" << endl;
+  kDebug() << "umounting" ;
   QString cmdS=umntcmd;
   if (cmdS.isEmpty()) // generate default umount cmd
       cmdS="umount %d";
@@ -129,10 +131,10 @@ int DiskEntry::umount()
   cmdS.replace(QString::fromLatin1("%d"),deviceName());
   cmdS.replace(QString::fromLatin1("%m"),mountPoint());
 
-  kdDebug() << "umount-cmd: [" << cmdS << "]" << endl;
+  kDebug() << "umount-cmd: [" << cmdS << "]" ;
   int e=sysCall(cmdS);
-  if (!e) setMounted(FALSE);
-  kdDebug() << "umount-cmd: e=" << e << endl;
+  if (!e) setMounted(false);
+  kDebug() << "umount-cmd: e=" << e ;
 
   return e;
 }
@@ -169,7 +171,7 @@ void DiskEntry::setUmountCommand(const QString & umnt)
 
 void DiskEntry::setIconName(const QString & iconName)
 {
-  iconSetByUser=TRUE;
+  iconSetByUser=true;
   icoName=iconName;
   if (icoName.right(6) == "_mount")
      icoName.truncate(icoName.length()-6);
@@ -193,24 +195,24 @@ QString DiskEntry::guessIconName()
 {
   QString iconName;
     // try to be intelligent
-    if (-1!=mountPoint().find("cdrom",0,FALSE)) iconName+="cdrom";
-    else if (-1!=deviceName().find("cdrom",0,FALSE)) iconName+="cdrom";
-    else if (-1!=mountPoint().find("writer",0,FALSE)) iconName+="cdwriter";
-    else if (-1!=deviceName().find("writer",0,FALSE)) iconName+="cdwriter";
-    else if (-1!=mountPoint().find("mo",0,FALSE)) iconName+="mo";
-    else if (-1!=deviceName().find("mo",0,FALSE)) iconName+="mo";
-    else if (-1!=deviceName().find("fd",0,FALSE)) {
-            if (-1!=deviceName().find("360",0,FALSE)) iconName+="5floppy";
-            if (-1!=deviceName().find("1200",0,FALSE)) iconName+="5floppy";
+    if (mountPoint().contains("cdrom",Qt::CaseInsensitive)) iconName+="cdrom";
+    else if (deviceName().contains("cdrom",Qt::CaseInsensitive)) iconName+="cdrom";
+    else if (mountPoint().contains("writer",Qt::CaseInsensitive)) iconName+="cdwriter";
+    else if (deviceName().contains("writer",Qt::CaseInsensitive)) iconName+="cdwriter";
+    else if (mountPoint().contains("mo",Qt::CaseInsensitive)) iconName+="mo";
+    else if (deviceName().contains("mo",Qt::CaseInsensitive)) iconName+="mo";
+    else if (deviceName().contains("fd",Qt::CaseInsensitive)) {
+            if (deviceName().contains("360",Qt::CaseInsensitive)) iconName+="5floppy";
+            if (deviceName().contains("1200",Qt::CaseInsensitive)) iconName+="5floppy";
             else iconName+="3floppy";
 	 }
-    else if (-1!=mountPoint().find("floppy",0,FALSE)) iconName+="3floppy";
-    else if (-1!=mountPoint().find("zip",0,FALSE)) iconName+="zip";
-    else if (-1!=fsType().find("nfs",0,FALSE)) iconName+="nfs";
+    else if (mountPoint().contains("floppy",Qt::CaseInsensitive)) iconName+="3floppy";
+    else if (mountPoint().contains("zip",Qt::CaseInsensitive)) iconName+="zip";
+    else if (fsType().contains("nfs",Qt::CaseInsensitive)) iconName+="nfs";
     else iconName+="hdd";
     mounted() ? iconName+="_mount" : iconName+="_unmount";
-//    if ( -1==mountOptions().find("user",0,FALSE) )
-//      iconName.prepend("root_"); // special root icon, normal user cant mount
+//    if ( !mountOptions().contains("user",Qt::CaseInsensitive) )
+//      iconName.prepend("root_"); // special root icon, normal user can't mount
 
     //debug("device %s is %s",deviceName().latin1(),iconName.latin1());
 
@@ -226,11 +228,11 @@ int DiskEntry::sysCall(const QString & command)
 {
   if (readingSysStdErrOut || sysProc->isRunning() )  return -1;
 
-  sysStringErrOut=i18n("Called: %1\n\n").arg(command); // put the called command on ErrOut
+  sysStringErrOut=i18n("Called: %1\n\n", command); // put the called command on ErrOut
   sysProc->clearArguments();
   (*sysProc) << command;
-    if (!sysProc->start( KProcess::Block, KProcess::AllOutput ))
-     kdFatal() << i18n("could not execute %1").arg(command.local8Bit().data()) << endl;
+    if (!sysProc->start( K3Process::Block, K3Process::AllOutput ))
+     kFatal() << i18n("could not execute %1", command.toLocal8Bit().data()) ;
 
   if (sysProc->exitStatus()!=0) emit sysCallError(this, sysProc->exitStatus());
 
@@ -241,7 +243,7 @@ int DiskEntry::sysCall(const QString & command)
 /***************************************************************************
   * is called, when the Sys-command writes on StdOut or StdErr
 **/
-void DiskEntry::receivedSysStdErrOut(KProcess *, char *data, int len)
+void DiskEntry::receivedSysStdErrOut(K3Process *, char *data, int len)
 {
   QString tmp = QString::fromLocal8Bit(data, len);
   sysStringErrOut.append(tmp);
@@ -265,15 +267,15 @@ void DiskEntry::setDeviceName(const QString & deviceName)
 QString DiskEntry::deviceRealName() const
 {
  QFileInfo inf( device );
- QDir dir( inf.dirPath( true ) );
+ QDir dir( inf.absolutePath() );
  QString relPath = inf.fileName();
  if ( inf.isSymLink() ) {
   QString link = inf.readLink();
-  if ( link.startsWith( "/" ) )
+  if ( link.startsWith( '/' ) )
     return link;
   relPath = link;
  }
- return dir.canonicalPath() + "/" + relPath;
+ return dir.canonicalPath() + '/' + relPath;
 }
 
 void DiskEntry::setMountPoint(const QString & mountPoint)
@@ -316,7 +318,7 @@ void DiskEntry::setKBUsed(int kb_used)
 {
   used=kb_used;
   if ( size < (used+avail) ) {  //adjust kBAvail
-     kdWarning() << "device " << device << ": kBAvail(" << avail << ")+*kBUsed(" << used << ") exceeds kBSize(" << size << ")" << endl;
+     kWarning() << "device " << device << ": kBAvail(" << avail << ")+*kBUsed(" << used << ") exceeds kBSize(" << size << ")" ;
      setKBAvail(size-used);
   }
   emit kBUsedChanged();
@@ -326,7 +328,7 @@ void DiskEntry::setKBAvail(int kb_avail)
 {
   avail=kb_avail;
   if ( size < (used+avail) ) {  //adjust kBUsed
-     kdWarning() << "device " << device << ": *kBAvail(" << avail << ")+kBUsed(" << used << ") exceeds kBSize(" << size << ")" << endl;
+     kWarning() << "device " << device << ": *kBAvail(" << avail << ")+kBUsed(" << used << ") exceeds kBSize(" << size << ")" ;
      setKBUsed(size-avail);
   }
   emit kBAvailChanged();
