@@ -93,7 +93,7 @@ KeyServer::KeyServer(QWidget *parent, const bool &modal, const bool &autoclose)
 
 void KeyServer::slotReadKeys(KgpgKeyList list, KgpgInterface *interface)
 {
-    delete interface;
+    interface->deleteLater();
     for (int i = 0; i < list.size(); ++i)
     {
         const KgpgKey key = list.at(i);
@@ -166,7 +166,7 @@ void KeyServer::slotDownloadKeysFinished(QList<int> result, QStringList keys, bo
 {
     delete m_importpop;
     m_importpop = 0;
-    delete interface;
+    interface->deleteLater();
 
     QApplication::restoreOverrideCursor();
 
@@ -225,7 +225,7 @@ void KeyServer::slotUploadKeysFinished(QString message, KgpgInterface *interface
 {
     delete m_importpop;
     m_importpop = 0;
-    delete interface;
+    interface->deleteLater();
 
     QApplication::restoreOverrideCursor();
 
@@ -273,7 +273,7 @@ void KeyServer::slotSearch()
     m_listpop->kLVsearch->setSelectionMode(QAbstractItemView::ExtendedSelection);
 
     m_count = 0;
-    m_keyid = QString();
+    m_keyid.clear();
     m_readmessage.clear();
     m_kitem = NULL;
 
@@ -396,7 +396,7 @@ void KeyServer::slotSetExportAttribute(const QString *state)
     if (state != 0)
         expattr = QString(*state);
     else
-        expattr = QString();
+        expattr.clear();
 }
 
 void KeyServer::slotEnableProxyI(const bool &on)
