@@ -57,7 +57,6 @@ KgpgEditor::KgpgEditor(QWidget *parent, Qt::WFlags f, KShortcut gohome, bool mai
           : KXmlGuiWindow(parent, f)
 {
     m_ismainwindow = mainwindow;
-    m_textencoding = QString();
     m_godefaultkey = gohome;
     m_find = 0;
 
@@ -619,7 +618,7 @@ void KgpgEditor::slotVerifyFile(const KUrl &url)
 {
     if (!url.isEmpty())
     {
-        QString sigfile = QString();
+        QString sigfile;
         if (!url.fileName().endsWith(".sig"))
         {
             sigfile = url.path() + ".sig";
